@@ -27,7 +27,7 @@ class CLIContext(TransformAuth):
         self.__user_state: Optional[UserState] = None
         self.__just_authenticated = False
         super().__init__()
-        self.mql = MQLClient()
+        self.mql = MQLClient(use_async=True)
 
     @property
     def api_key(self) -> Optional[str]:  # noqa: D
